from setuptools import setup

setup(name='stats_distrib',
      version='1.0',
      description='Gaussian & Binomial distributions implementation in Python',
      packages=['stats_distrib'],
      zip_safe=False)
